function [s] = AgreeImprove(s)
%% only study 1 & 3
% 1. averages across scales
% 2. Plots the frequency and imrpovement scores of each scale


clc;
names = {'emotover' ;' neg_selftalk'; 'neg_selfimage'; 'interconf'; 'EmotIso'; };


%% 1. get scores:

idx = [1 3];

for is = 1:length(idx)
    
    if is ==1 % study 1
        
        Fname = {'averageEmotionalOverwhelm';'averageNegativeSelfTalk';'averageNegativeSelfImage';...
            'averageInterpersonalConflict';'averageIsolationEmotionExperience'; 'averageSelfCompassion';...
            'averageLackEmotionalClarity';'averageEmotionalExpression'};
        
        Iname = {'improvement_moreControlOfEmotions';'improvement_lessNegativeSelfTalk';'improvement_morePositiveSelfImage';...
            'improvement_lessConflict';'improvement_lessIsolatedInMyEmotions'; 'improvement_moreSelfCompassion';...
            'improvement_emotionalClarity';'improvement_expressFeelingsMoreOften'};
        
        
        freqmat{is} = get_from_mat(s.dat{idx(is)}.pmat, Fname);
        impmat{is}  = get_from_mat(s.dat{idx(is)}.pmat, Iname);
        
        s.dat{idx(is)}.avgfreqmat = freqmat;
        s.dat{idx(is)}.impmat = impmat;
    elseif is == 2 % study 3
        
        Fname = {'averageEmotionalOverwhelm';'averageNegativeSelfTalk';'averageNegativeSelfImage';...
            'averageInterpersonalConflict';'averageIsolationEmotionExperience'};
        
        Iname = {'improvement_moreControlOfEmotions';'improvement_lessNegativeSelfTalk';'improvement_morePositiveSelfImage';...
            'improvement_lessConflict';'improvement_lessIsolatedInMyEmotions'};
        
        freqmat{is} = get_from_mat(s.dat{idx(is)}.pmat, Fname);
        impmat{is}  = get_from_mat(s.dat{idx(is)}.pmat, Iname);
        s.dat{idx(is)}.avgfreqmat = freqmat;
        s.dat{idx(is)}.impmat = impmat;
    end
    
    
end





%% 2. plot:
% only the common ones across study 1,3 are plotted
for ivar = 1:5
    Fcurmean(ivar) = nanmean([freqmat{1}(:,ivar) ;freqmat{2}(:,ivar)]);
    FcurSE(ivar) = getnanSE([freqmat{1}(:,ivar) ;freqmat{2}(:,ivar)]);
    
    Icurmean(ivar) = nanmean([impmat{1}(:,ivar) ;impmat{2}(:,ivar)]);
    IcurSE(ivar) = getnanSE([impmat{1}(:,ivar) ;impmat{2}(:,ivar)]);
end

cols = {'xg';'xb'};

% --- Agreement
figure
subplot(1,2,1)
title('Agreement score'); hold all;

for ivar = 1:5
    bar(ivar, Fcurmean(ivar));hold all;
    errorbar(ivar, Fcurmean(ivar),FcurSE(ivar),'k');hold all;
    
    % individual studies:
    for is = 1:2
        plt{is}=plot(ivar+is/10, nanmean(freqmat{is}(:,ivar)),cols{is},'LineWidth',2);
        errorbar(ivar+is/10, nanmean(freqmat{is}(:,ivar)), getnanSE(freqmat{is}(:,ivar)),cols{is},'LineWidth',2);
        
    end
end
legend([plt{:}],{'Study1';'Study3'})
set(gca,'XTick',1: length(Fcurmean));
set(gca,'XTickLabel',names,'FontSize',12);
xtickangle(45)
set_default_fig_properties(gca,gcf);hold all;
ylabel('Agrrement Score')
ylim([-3 1.5])


% --- Improvment

subplot(1,2,2)
title('Improvement score'); hold all;

for ivar = 1:5
    bar(ivar, Icurmean(ivar));hold all;
    errorbar(ivar, Icurmean(ivar),IcurSE(ivar),'k');hold all;
    
    % individual studies:
    for is = 1:2
        plt{is}=plot(ivar+is/10, nanmean(impmat{is}(:,ivar)),cols{is},'LineWidth',2);
        errorbar(ivar+is/10, nanmean(impmat{is}(:,ivar)), getnanSE(impmat{is}(:,ivar)),cols{is},'LineWidth',2);
        
    end
end
legend([plt{:}],{'Study1';'Study3'})
set(gca,'XTick',1: length(Icurmean));
set(gca,'XTickLabel',names,'FontSize',12);
xtickangle(45)
set_default_fig_properties(gca,gcf);hold all;
ylabel('Improvement Score')
ylim([-1.5 1.5])

















end