function [s] = GLMindivitems(s)
%% GLM analysis predicting life quality and depression by all items within most predictive psychogical factors
% each GLM only includes items from the most predictive factors to test
% in particular which individual items predict depression or life quality (i.e. highest regression coefficient) 

% note that items are derived from Study 3, which includes more refined
% items (see article). The approach that was used was:
% a) separate regression analysis for negtaive self-talk and emot overwhelm
% predictin depression
% b) identify most predictive items, then merge into a single GLM analysis
% to dermine the unique explained variance 


%% Depression
% -~-~-~-~-~-~ Depression <- negative self-talk and emotional overwhelm

% ------ Study 3 -----
negstalk=[];emotover=[];
negstalk = {'x_ifIWorkHardEnough_IWillSucceed___agovizp_';'x_IShouldNotFeelThisWay___8mw8a0y_';'x_IWillNotGetThroughThis___tstmsp7_';'x_ItIsAllMyFault___ej3jqmi_';...
    'x_IAmGoingToFail__cjq4qo9_';'x_noOneCaresAboutMe___7ktwotf_';'x_ILookStupid___qv180bl_';...
    'x_ISuckOrIAmAFailure___x7m5l80_';'x_IDon___tDeserveToBeHappyOrDon___tDeserveToBeLoved__'};

emotover = {'WhenIAmUpset_ThatFeelingTakesOverCompletely__z7t7imt_';'FeelingUpsetOrAnxiousStopsMeFromGettingThingsDone__jv';'ILoseMyTemperQuickly__sn3yplb_';...
    'WhenIAmUpset_IOftenDoOrSayThingsILaterRegret__twtc';'IfIFeelUpsetAboutOneThing_IEasilyGetUpsetAboutOther';'IDon___tKnowHowToTakeControlOverMyEmotions__10gdinx_';...
    'IUsuallyHaveInsightIntoMyEmotionalState_WhichHelpsTo';'WhenSomethingPainfulHappens_ITendToTakeTheIncidentOut';'WhenSomethingPainfulHappens_ITryToTakeABalancedViewO'};
    
    
allnames = [negstalk;emotover];

dep_s3 = nannormalise(s.dat{3}.outvar(:,2));


% 1) negative self-talk -> depression
stalk = nannormalise(get_from_mat(s.dat{3}.pmat, [negstalk]));
[a,b,c]=glmfit(stalk,dep_s3);
a(1) =[]; % delete constant
figure
subplot(1,3,1)
title('GLM: negative self-talk items -> depression');hold all;
bar(1:length(a), a)
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(negstalk));
set(gca,'XTickLabel',negstalk,'FontSize',12);
xtickangle(45)
ylabel('depression effect size a.u.')

% 2) emot over -> depression
emotov = nannormalise(get_from_mat(s.dat{3}.pmat, [emotover]));
[d,e,f]=glmfit(emotov,dep_s3);
d(1) =[]; % delete constant
subplot(1,3,2)
title('GLM: emot overwhelm items -> depression');hold all;
bar(1:length(d), d)
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(emotover));
set(gca,'XTickLabel',emotover,'FontSize',12);
xtickangle(45)
ylabel('depression effect size a.u.')

% 3) merged emot over and neg self-talk: only most predictive items from
% each factor:

shortlist = {'x_IShouldNotFeelThisWay___8mw8a0y_';'x_IAmGoingToFail__cjq4qo9_';'x_noOneCaresAboutMe___7ktwotf_';'x_IDon___tDeserveToBeHappyOrDon___tDeserveToBeLoved__';...
    'FeelingUpsetOrAnxiousStopsMeFromGettingThingsDone__jv';'ILoseMyTemperQuickly__sn3yplb_';'IDon___tKnowHowToTakeControlOverMyEmotions__10gdinx_'};

shortvar = nannormalise(get_from_mat(s.dat{3}.pmat, [shortlist]));
[g,h,i]=glmfit(shortvar,dep_s3);
g(1) =[]; % delete constant
subplot(1,3,3)
title('GLM: merged items -> depression');hold all;
bar(1:length(g), g)
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(shortlist));
set(gca,'XTickLabel',shortlist,'FontSize',12);
xtickangle(45)
ylabel('depression effect size a.u.')



%% Life Quality 
% -~-~-~-~-~-~ Life Quality <- negative self-image and emotional isolation

% -- items for each scale:
emotiso = {'WhenIFailAtSomethingThatIsImportantToMe_IReceiveGoo';'WhenIAmFeelingBad_IRemindMyselfThatOthersStruggleAs';'WhenIAmReallyStruggling_ITendToFeelLikeOtherPeopleM';'WhenThingsAreGoingBadlyForMe_ISeeTheDifficultiesAsP'};
simage  = {'IAmProudOfMyself__2duccfw_';'IAmProudOfMyselfWhenIAchieveSomethingThatIsImportant';'RegardlessOfWhetherIAchieveALittleOrALot_IThinkIAm';'IHaveALowOpinionOfMyself__ul1dcqq_'};
merged = {'WhenIFailAtSomethingThatIsImportantToMe_IReceiveGoo';'WhenIAmReallyStruggling_ITendToFeelLikeOtherPeopleM';'WhenThingsAreGoingBadlyForMe_ISeeTheDifficultiesAsP';...
    'IAmProudOfMyself__2duccfw_';'RegardlessOfWhetherIAchieveALittleOrALot_IThinkIAm'};

LQ = nannormalise(s.dat{3}.outvar(:,1));

emotiso_var = nannormalise(get_from_mat(s.dat{3}.pmat, emotiso));
simage_var = nannormalise(get_from_mat(s.dat{3}.pmat, simage));
short_var = nannormalise(get_from_mat(s.dat{3}.pmat, merged));

% - GLM1:
a=[];
[a,b,c]=glmfit(emotiso_var,LQ);
a(1) =[]; % delete constant
figure
subplot(1,3,1)
title('GLM: emot isolation items -> life quality');hold all;

bar(1:length(a), a)
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(emotiso));
set(gca,'XTickLabel',emotiso,'FontSize',12);
xtickangle(45)
ylabel('life quality effect size a.u.')

% - GLM2:
d=[];
[d,e,f]=glmfit(simage_var,LQ);
d(1) =[]; % delete constant
subplot(1,3,2)
title('GLM: negative self-image items -> life quality');hold all;
bar(1:length(d), d)
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(simage));
set(gca,'XTickLabel',simage,'FontSize',12);
xtickangle(45)
ylabel('life quality effect size a.u.')

% - GLM3:
g=[];
[g,h,i]=glmfit(short_var,LQ);
g(1) =[]; % delete constant
subplot(1,3,3)
title('GLM: merged items -> life quality');hold all;
bar(1:length(g), g)
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(merged));
set(gca,'XTickLabel',merged,'FontSize',12);
xtickangle(45)
ylabel('life quality effect size a.u.')






















end