function [s] = PairCorr(s)
%% pairwise correlation
% calculates pairwise correlation between frequency and outcome meausres
% only study 1

%% scales
name = {'depr';'EmotOver';'negselftalk';'negselfimg';...
    'interconf';'emotiso'; 'selfcomp';...
    'emotclar';'emotexp'};

Freqscore = s.dat{1}.avgfreqmat{1};
DepScore  = get_from_mat(s.dat{1}.pmat, 'phq9DepressionScore0to1Scale');


%% ---- Depression
allvar = [DepScore Freqscore];

% -- correlation matrix
figure
title('Correlation matrix: Depression & all 8 psych factors'); hold all;
imagesc(corrcoef(allvar,'Rows','complete'),[0 1]);hold all;
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(name));
set(gca,'XTickLabel',name,'FontSize',12);
set(gca,'YTick',1: length(name));
set(gca,'YTickLabel',name,'FontSize',12);
xtickangle(45)


% -- bar graph 

figure
title('Correlation bars: Depression & all 8 psych factors'); hold all;
tmpr = corrcoef(allvar,'Rows','complete');
bar(tmpr(1,2:end)); hold all;
ylabel('correlation index')
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(name));
set(gca,'XTickLabel',name,'FontSize',12);
xtickangle(45)
ylim([0 1])


%% ---- Life quality



name = {'LifeQuality';'EmotOver';'negselftalk';'negselfimg';...
    'interconf';'emotiso'; 'selfcomp';...
    'emotclar';'emotexp'};

LifeQ = s.dat{1}.outvar(:,1);
allvar = [LifeQ Freqscore];

% -- correlation matrix
figure
title('Correlation matrix: Life quality & all 8 psych factors'); hold all;
avgcorr = corrcoef(allvar,'Rows','complete');
N=length(name);
imagesc(avgcorr,[-1 1]);hold all;
x = repmat(1:N,N,1); % generate x-coordinates
y = x'; % generate y-coordinates
t = num2cell(round(avgcorr,2)); % extact values into cells
t = cellfun(@num2str, t, 'UniformOutput', false); % convert to string
text(x(:), y(:), t, 'HorizontalAlignment', 'Center')
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(name));
set(gca,'XTickLabel',name,'FontSize',12);
set(gca,'YTick',1: length(name));
set(gca,'YTickLabel',name,'FontSize',12);
xtickangle(45)



% -- bar graph 

figure
title('Correlation bars: Life quality & all 8 psych factors'); hold all;
tmpr = corrcoef(allvar,'Rows','complete');
bar(tmpr(1,2:end)); hold all;
ylabel('correlation index')
set_default_fig_properties(gca,gcf);hold all;
set(gca,'XTick',1: length(name));
set(gca,'XTickLabel',name,'FontSize',12);
xtickangle(45)
ylim([-1 0.1])
end